raytraverse.craytraverse
==========================================================

.. automodule:: raytraverse.craytraverse
    :members:
    :undoc-members:
    :show-inheritance:

cRtrace
--------------------------------

.. autoclass:: raytraverse.crenderer.cRtrace
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

cRcontrib
--------------------------------

.. autoclass:: raytraverse.crenderer.cRcontrib
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members: